summaryrefslogtreecommitdiffstats
path: root/core/jni
diff options
context:
space:
mode:
authorMartijn Coenen <maco@google.com>2015-05-26 08:11:26 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2015-05-26 08:11:28 +0000
commit99fbb56a0ab81ead404480f0c2df529332a93a32 (patch)
tree8fd72880fbde332f008842202f082242ac42c4c9 /core/jni
parent912696e79785ad26bb2f27354bedce1739f311e3 (diff)
parentab3576e58a8d3965f57473e03ec8de69ae13404b (diff)
downloadframeworks_base-99fbb56a0ab81ead404480f0c2df529332a93a32.zip
frameworks_base-99fbb56a0ab81ead404480f0c2df529332a93a32.tar.gz
frameworks_base-99fbb56a0ab81ead404480f0c2df529332a93a32.tar.bz2
Merge "Don't count lowmem mappings as memory used." into mnc-dev
Diffstat (limited to 'core/jni')
-rw-r--r--core/jni/android_os_Debug.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/jni/android_os_Debug.cpp b/core/jni/android_os_Debug.cpp
index 2692ad8..e8acd97 100644
--- a/core/jni/android_os_Debug.cpp
+++ b/core/jni/android_os_Debug.cpp
@@ -580,8 +580,8 @@ static long get_allocated_vmalloc_memory() {
break;
}
- if (!strstr(line, "ioremap")) {
- // Ignore ioremap regions, since they don't actually consume memory
+ if (!strstr(line, "ioremap") && !strstr(line, "map_lowmem")) {
+ // Ignore ioremap and map_lowmem regions, since they don't actually consume memory
if (sscanf(line, "%*x-%*x %ld", &size) == 1) {
vmalloc_allocated_size += size;
}